==> spip_4.0.4.orig.tar.xz: plugins-dist/medias/lang/medias_km.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=km
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_ajouter_document' => 'បន្ថែម មួយ​ឯកសារ',
	'bouton_ajouter_image' => 'បន្ថែម​ មួយរូបភាព',
	'bouton_ajouter_image_document' => 'បន្ថែម មួយរូបភាព ឬ មួយឯកសារ',

	// D
	'double_clic_inserer_doc' => 'ចុច​ផ្ទួន ​ដើម្បី​បញ្ចូល ផ្លូវ​កាត់​នេះ ​ក្នុង​អត្ថបទ',

	// E
	'entree_dimensions' => 'ខ្មាត ៖',
	'entree_titre_document' => 'ចំណងជើង ​ឯកសារ៖',
	'entree_titre_image' => 'ចំណងជើង ​រូបភាព៖',

	// I
	'image_tourner_180' => 'បង្វិល ១៨០ អង្សា',
	'image_tourner_droite' => 'បង្វិល ៩០ អង្សា ទៅ​ស្ដាំ',
	'image_tourner_gauche' => 'បង្វិល ៩០ អង្សា ទៅ​ឆ្វេង',
	'info_document' => 'ឯកសារ ៖',
	'info_document_indisponible' => 'ឯកសារនេះ គ្មានស្រាប់',
	'info_documents' => 'ឯកសារ',
	'info_inclusion_directe' => 'ការ​រួមបញ្ចូល​ ដោយ​ផ្ទាល់ ៖',
	'info_inclusion_vignette' => 'ការរួមបញ្ចូល កូន​រូបភាព ៖',
	'info_installer_tous_documents' => 'តំលើង គ្រប់ឯកសារ',
	'info_logo_max_taille' => 'រូប​សញ្ញា​ ត្រូវ​តែ​តិច​ជាង @maxi@ (​សំណុំឯកសារនេះ​ មាន @actuel@)។',
	'info_portfolio' => 'ផលប័ត្រ',
	'info_referencer_doc_distant' => 'យោង មួយឯកសារ លើអិនរើណែត ៖',
	'info_telecharger' => 'ផ្ទុក​ឡើង​ ពី​ខំព្យូរើ របស់​អ្នក ៖',

	// T
	'texte_documents_joints' => 'លោក​អ្នក​អាច​អនុញ្ញាត​ចំពោះ​ការ​បន្ថែម​ឯកសារ (​ហ្វា​ល​អត្ថបទ រូបភាព ឬ​ភាពយន្ដ​។​ល​។​) ចូល​ទៅ​ក្នុង​អត្ថបទ និង​/​ឬ​ផ្នែក​។ ដូច្នេះ ហ្វា​ល​ទាំងនេះ​អាច​យោង​នៅ​ក្នុង​អត្ថបទ ឬ​ត្រូវ​បាន​បង្ហាញ​ដាច់​ដោយឡែក​។', # MODIF
	'texte_documents_joints_2' => 'ការ​កំណត់​នេះ​មិន​បញ្ឈប់​ការ​បញ្ចូល​រូបភាព​ទោ​ក្នុង​អត្ថបទ​នេះ​ដោយ​ផ្ទាល់​នោះ​ទេ​។', # MODIF
	'titre_documents_joints' => 'ឯកសារ​ភ្ជាប់',
	'tout_dossier_upload' => 'ថតឯកសារ @upload@ ទាំងមូល',

	// U
	'upload_fichier_zip' => 'សំណុំឯកសារ ZIP',
	'upload_fichier_zip_texte' => 'សំណុំឯកសារ ​ដែល​អ្នកស្នើតំលើង ជា មួយសំណុំឯកសារ ZIP',
	'upload_fichier_zip_texte2' => 'ឯកសារ​នេះ ​អាច​ជា ៖',
	'upload_limit' => 'សំណុំឯកសារ​នេះ មានទំហំ​ធំ​ពេក សំរាប់ខំព្យូរើបំរើសេវា ; ទំហំ​អតិបរិមា ត្រូវបានអនុញ្ញាតិ <i>​ផ្ទុកឡើង​</i> គឺ @max@។',
	'upload_zip_decompacter' => 'បានពន្លាត និង សំណុំឯកសារនីមួយៗ ដែលវាមានផ្ទុក ត្រូវ​បានតំលើង លើសៃថ៍។ សំណុំឯកសារ នឹងត្រូវបានតំលើង លើសៃថ៍ គឺ៖',
	'upload_zip_telquel' => 'បានតំលើង តាមដំណើរ, ជាទំរង់បណ្ណសារ ត្រូវបានបង្ហាប់ ZIP ;'
);

==> spip_4.4.7+dfsg.orig.tar.xz: plugins-dist/medias/lang/medias_km.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=km
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_ajouter_document' => 'បន្ថែម មួយ​ឯកសារ',
	'bouton_ajouter_image' => 'បន្ថែម​ មួយរូបភាព',
	'bouton_ajouter_image_document' => 'បន្ថែម មួយរូបភាព ឬ មួយឯកសារ',

	// D
	'double_clic_inserer_doc' => 'ចុច​ផ្ទួន ​ដើម្បី​បញ្ចូល ផ្លូវ​កាត់​នេះ ​ក្នុង​អត្ថបទ',

	// E
	'entree_dimensions' => 'ខ្មាត ៖',
	'entree_titre_document' => 'ចំណងជើង ​ឯកសារ៖',
	'entree_titre_image' => 'ចំណងជើង ​រូបភាព៖',

	// I
	'image_tourner_180' => 'បង្វិល ១៨០ អង្សា',
	'image_tourner_droite' => 'បង្វិល ៩០ អង្សា ទៅ​ស្ដាំ',
	'image_tourner_gauche' => 'បង្វិល ៩០ អង្សា ទៅ​ឆ្វេង',
	'info_document' => 'ឯកសារ ៖',
	'info_document_indisponible' => 'ឯកសារនេះ គ្មានស្រាប់',
	'info_documents' => 'ឯកសារ',
	'info_inclusion_directe' => 'ការ​រួមបញ្ចូល​ ដោយ​ផ្ទាល់ ៖',
	'info_inclusion_vignette' => 'ការរួមបញ្ចូល កូន​រូបភាព ៖',
	'info_installer_tous_documents' => 'តំលើង គ្រប់ឯកសារ',
	'info_logo_max_taille' => 'រូប​សញ្ញា​ ត្រូវ​តែ​តិច​ជាង @maxi@ (​សំណុំឯកសារនេះ​ មាន @actuel@)។',
	'info_portfolio' => 'ផលប័ត្រ',
	'info_referencer_doc_distant' => 'យោង មួយឯកសារ លើអិនរើណែត ៖',
	'info_telecharger' => 'ផ្ទុក​ឡើង​ ពី​ខំព្យូរើ របស់​អ្នក ៖',

	// T
	'texte_documents_joints' => 'លោក​អ្នក​អាច​អនុញ្ញាត​ចំពោះ​ការ​បន្ថែម​ឯកសារ (​ហ្វា​ល​អត្ថបទ រូបភាព ឬ​ភាពយន្ដ​។​ល​។​) ចូល​ទៅ​ក្នុង​អត្ថបទ និង​/​ឬ​ផ្នែក​។ ដូច្នេះ ហ្វា​ល​ទាំងនេះ​អាច​យោង​នៅ​ក្នុង​អត្ថបទ ឬ​ត្រូវ​បាន​បង្ហាញ​ដាច់​ដោយឡែក​។', # MODIF
	'texte_documents_joints_2' => 'ការ​កំណត់​នេះ​មិន​បញ្ឈប់​ការ​បញ្ចូល​រូបភាព​ទោ​ក្នុង​អត្ថបទ​នេះ​ដោយ​ផ្ទាល់​នោះ​ទេ​។', # MODIF
	'titre_documents_joints' => 'ឯកសារ​ភ្ជាប់',
	'tout_dossier_upload' => 'ថតឯកសារ @upload@ ទាំងមូល',

	// U
	'upload_fichier_zip' => 'សំណុំឯកសារ ZIP',
	'upload_fichier_zip_texte' => 'សំណុំឯកសារ ​ដែល​អ្នកស្នើតំលើង ជា មួយសំណុំឯកសារ ZIP',
	'upload_fichier_zip_texte2' => 'ឯកសារ​នេះ ​អាច​ជា ៖',
	'upload_limit' => 'សំណុំឯកសារ​នេះ មានទំហំ​ធំ​ពេក សំរាប់ខំព្យូរើបំរើសេវា ; ទំហំ​អតិបរិមា ត្រូវបានអនុញ្ញាតិ <i>​ផ្ទុកឡើង​</i> គឺ @max@។',
	'upload_zip_decompacter' => 'បានពន្លាត និង សំណុំឯកសារនីមួយៗ ដែលវាមានផ្ទុក ត្រូវ​បានតំលើង លើសៃថ៍។ សំណុំឯកសារ នឹងត្រូវបានតំលើង លើសៃថ៍ គឺ៖',
	'upload_zip_telquel' => 'បានតំលើង តាមដំណើរ, ជាទំរង់បណ្ណសារ ត្រូវបានបង្ហាប់ ZIP ;',
];
